//@line 36 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/browser/locales/en-US/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/browser/locales/en-US/firefox-l10n.js"

pref("general.useragent.locale", "en-US");
